@@ -13,7 +13,7 @@ library(nnet)
 
 # 12.1  Discriminant Analysis
 
-data(iris3); ir <- rbind(iris3[,,1], iris3[,,2], iris3[,,3])
+ir <- rbind(iris3[,,1], iris3[,,2], iris3[,,3])
 ir.species <- factor(c(rep("s", 50), rep("c", 50), rep("v", 50)))
 
 (ir.lda <- lda(log(ir), ir.species))
@@ -46,7 +46,6 @@ perp <- function(x, y) {
    abline(c(m[2] - s*m[1], s))
    invisible()
 }
-# For R replace @means by $means
 cr.m <- lda(cr.t, crabs$sex)$means
 points(cr.m, pch = 3, mkh = 0.3)
 perp(cr.m[1, ], cr.m[2, ])
@@ -189,10 +188,10 @@ plt.bndry <- function(size=0, decay=0, ...)
 b1 <- function(Z, ...)
 {
    zp <- Z[,3] - pmax(Z[,2], Z[,1])
-   contour(xp/log(10), yp/log(10), matrix(zp, np),
+   contour(exp(xp), exp(yp), matrix(zp, np),
       add=T, levels=0, labex=0, ...)
    zp <- Z[,1] - pmax(Z[,3], Z[,2])
-   contour(xp/log(10), yp/log(10), matrix(zp, np),
+   contour(exp(xp), exp(yp), matrix(zp, np),
       add=T, levels=0, labex=0, ...)
 }
 
